import unittest
from plugins.xss import XSSPlugin

class TestXSSPlugin(unittest.TestCase):
    def test_run_returns_output(self):
        plugin = XSSPlugin()
        result = plugin.run("https://example.com")
        self.assertTrue(isinstance(result, str))

if __name__ == "__main__":
    unittest.main()
