import argparse

def main():
    parser = argparse.ArgumentParser(
        description="Vibe PentesterLab - CLI Tool"
    )

    parser.add_argument(
        "--version", action="store_true", help="Show version"
    )

    args = parser.parse_args()

    if args.version:
        from vibe_pentesterlab import __version__
        print(f"Vibe PentesterLab CLI - Version {__version__}")
    else:
        print("Run vibe --version to check version or add more commands.")

if __name__ == "__main__":
    main()