from setuptools import setup, find_packages

setup(
    name='vibe-pentesterlab',
    version='2.0.1',
    author='Prajeesh KC',
    author_email='vp.prajeesh2@gmail.com',
    description='AI-Assisted Offensive Security Framework',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/kcprajeesh/vibe-pentesterlab',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    entry_points={
        'console_scripts': [
            'vibe=vibe_pentesterlab.cli:main'
        ],
    },
    python_requires='>=3.8',
    include_package_data=True,
)